# AI Labeler
AI Labeler labels images and videos.

* https://spacecruft.org/deepcrayon/ailabeler
* https://pypi.org/project/ailabeler/

# Installation
Thusly, suit to taste:

```
git clone https://spacecruft.org/deepcrayon/ailabeler
cd ailabeler/
python -m venv venv
source venv/bin/activate
pip install -U setuptools pip wheel
pip install ailabeler
```

# Fork
AI Labeler is a fork of GPLv3 licensed X-AnyLabeling.

* https://github.com/CVHub520/X-AnyLabeling

SAM2 is a fork of Apache 2.0 licensed Segment Anything 2 from CVHub.

* https://github.com/CVHub520/segment-anything-2

CVHub forked Apache 2.0 licensed SAM2 from Facebook.

* https://github.com/facebookresearch/sam2

This AI Labeler fork has fewer features than upstream, but should be easier to
install and has everything setup including SAM2 "out-of-the-box".

# License
GPLv3.

Unofficial project, not related to upstream projects.

Upstream sources under their respective copyrights.

*Copyright &copy; 2025 Jeff Moe.*
